@@ -5,6 +5,7 @@ import functools
 import itertools
 import logging
 import multiprocessing
+import sys
 from pathlib import Path
 from typing import Any, Collection, Optional
 
@@ -17,12 +18,13 @@ from annoworkapi.resource import Resource as AnnoworkResource
 
 import annoworkcli
 from annoworkcli.actual_working_time.list_actual_working_hours_daily import (
+    ActualWorkingHoursDaily,
     create_actual_working_hours_daily_list,
     filter_actual_daily_list,
 )
 from annoworkcli.actual_working_time.list_actual_working_time import ListActualWorkingTime
 from annoworkcli.common.annofab import TIMEZONE_OFFSET_HOURS, get_annofab_project_id_from_job, isoduration_to_hour
-from annoworkcli.common.cli import OutputFormat, build_annoworkapi, get_list_from_args
+from annoworkcli.common.cli import COMMAND_LINE_ERROR_STATUS_CODE, OutputFormat, build_annoworkapi, get_list_from_args
 from annoworkcli.common.utils import print_csv, print_json
 
 logger = logging.getLogger(__name__)
@@ -116,8 +118,7 @@ class ListWorkingHoursWithAnnofab:
         job_ids: Optional[Collection[str]] = None,
         parent_job_ids: Optional[Collection[str]] = None,
         user_ids: Optional[Collection[str]] = None,
-        is_show_notes: bool = False,
-    ):
+    ) -> list[ActualWorkingHoursDaily]:
         actual_working_time_list = self.list_actual_working_time_obj.get_actual_working_times(
             job_ids=job_ids,
             parent_job_ids=parent_job_ids,
@@ -129,7 +130,7 @@ class ListWorkingHoursWithAnnofab:
         self.list_actual_working_time_obj.set_additional_info_to_actual_working_time(actual_working_time_list)
 
         result = create_actual_working_hours_daily_list(
-            actual_working_time_list, timezone_offset_hours=TIMEZONE_OFFSET_HOURS, show_notes=is_show_notes
+            actual_working_time_list, timezone_offset_hours=TIMEZONE_OFFSET_HOURS
         )
         result = filter_actual_daily_list(result, start_date=start_date, end_date=end_date)
         return result
@@ -256,7 +257,7 @@ class ListWorkingHoursWithAnnofab:
         return df[["job_id", "parent_job_id", "parent_job_name"]]
 
     @staticmethod
-    def _get_required_columns(is_show_parent_job: bool, is_show_notes: bool):
+    def _get_required_columns(is_show_parent_job: bool):
         job_columns = [
             "job_id",
             "job_name",
@@ -279,8 +280,7 @@ class ListWorkingHoursWithAnnofab:
         else:
             required_columns = ["date"] + job_columns + user_columns + ["actual_working_hours"] + annofab_columns
 
-        if is_show_notes:
-            required_columns.append("notes")
+        required_columns.append("notes")
         return required_columns
 
     def get_df_working_hours(
@@ -291,7 +291,6 @@ class ListWorkingHoursWithAnnofab:
         job_ids: Optional[Collection[str]] = None,
         user_ids: Optional[Collection[str]] = None,
         is_show_parent_job: bool = False,
-        is_show_notes: bool = False,
     ) -> pandas.DataFrame:
         def _get_start_date(df: pandas.DataFrame) -> str:
             if start_date is None:
@@ -304,7 +303,7 @@ class ListWorkingHoursWithAnnofab:
             return max(end_date, df["date"].max())
 
         actual_working_hours_daily_list = self.get_actual_working_hours_daily(
-            job_ids=job_ids, user_ids=user_ids, start_date=start_date, end_date=end_date, is_show_notes=is_show_notes
+            job_ids=job_ids, user_ids=user_ids, start_date=start_date, end_date=end_date
         )
 
         df_actual_working_hours = pandas.DataFrame(actual_working_hours_daily_list)
@@ -344,7 +343,7 @@ class ListWorkingHoursWithAnnofab:
             df = df.merge(df_job_parent_job, how="left", on="job_id")
 
         df.sort_values(["date", "job_id", "user_id"], inplace=True)
-        required_columns = self._get_required_columns(is_show_parent_job, is_show_notes)
+        required_columns = self._get_required_columns(is_show_parent_job)
         return df[required_columns]
 
     def get_job_id_list_from_parent_job_id_list(self, parent_job_id_list: Collection[str]) -> list[str]:
@@ -370,9 +369,18 @@ def main(args):
 
     job_id_list = get_list_from_args(args.job_id)
     parent_job_id_list = get_list_from_args(args.parent_job_id)
-    user_id_list = get_list_from_args(args.user_id)
     annofab_project_id_list = get_list_from_args(args.annofab_project_id)
-    is_show_notes = args.show_notes
+    user_id_list = get_list_from_args(args.user_id)
+    start_date: Optional[str] = args.start_date
+    end_date: Optional[str] = args.end_date
+
+    command = " ".join(sys.argv[0:3])
+    if all(
+        v is None
+        for v in [job_id_list, parent_job_id_list, annofab_project_id_list, user_id_list, start_date, end_date]
+    ):
+        print(f"{command}: error: '--start_date'や'--job_id'などの絞り込み条件を1つ以上指定してください。", file=sys.stderr)
+        sys.exit(COMMAND_LINE_ERROR_STATUS_CODE)
 
     main_obj = ListWorkingHoursWithAnnofab(
         annowork_service=build_annoworkapi(args),
@@ -388,12 +396,11 @@ def main(args):
         job_id_list = main_obj.get_job_id_list_from_annofab_project_id_list(annofab_project_id_list)
 
     df = main_obj.get_df_working_hours(
-        start_date=args.start_date,
-        end_date=args.end_date,
+        start_date=start_date,
+        end_date=end_date,
         job_ids=job_id_list,
         user_ids=user_id_list,
         is_show_parent_job=args.show_parent_job,
-        is_show_notes=is_show_notes,
     )
 
     if len(df) == 0:
@@ -443,12 +450,6 @@ def parse_args(parser: argparse.ArgumentParser):
         help="親のジョブ情報も出力します。",
     )
 
-    parser.add_argument(
-        "--show_notes",
-        action="store_true",
-        help="実績の備考も出力します。",
-    )
-
     parser.add_argument("-o", "--output", type=Path, help="出力先")
 
     parser.add_argument(
